@@ -11,7 +11,7 @@ use Env qw( @PKG_CONFIG_PATH );
 use Config ();
 
 # ABSTRACT: Build external dependencies for use in CPAN
-our $VERSION = '0.70_01'; # TRIAL VERSION
+our $VERSION = '0.71_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -305,6 +305,13 @@ sub load_requires
       }
     }
     
+    # sufficiently new Autotools have a aclocal_dir which will
+    # give us the directories we need.
+    if($mod eq 'Alien::Autotools' && $mod->can('aclocal_dir'))
+    {
+      push @{ $self->{aclocal_path} }, $mod->aclocal_dir;
+    }
+    
     if($mod->can('alien_helper'))
     {
       my $helpers = $mod->alien_helper;
@@ -952,7 +959,7 @@ Alien::Build - Build external dependencies for use in CPAN
 
 =head1 VERSION
 
-version 0.70_01
+version 0.71_01
 
 =head1 SYNOPSIS
 
@@ -1596,6 +1603,41 @@ be used by some Fetch plugins, if they support it.
 
 =back
 
+=head1 SUPPORT
+
+The intent of the C<Alien-Build> team is to support as best as possible 
+all Perls from 5.8.1 to the latest production version.  So long as they 
+are also supported by the Perl toolchain.
+
+Please feel encouraged to report issues that you encounter to the 
+project GitHub Issue tracker:
+
+=over 4
+
+=item L<https://github.com/Perl5-Alien/Alien-Build/issues>
+
+=back
+
+Better if you can fix the issue yourself, please feel encouraged to open 
+pull-request on the project GitHub:
+
+=over 4
+
+=item L<https://github.com/Perl5-Alien/Alien-Build/pulls>
+
+=back
+
+If you are confounded and have questions, join us on the C<#native> 
+channel on irc.perl.org.  The C<Alien-Build> developers frequent this 
+channel and can probably help point you in the right direction.  If you
+don't have an IRC client handy, you can use this web interface:
+
+=over 4
+
+=item L<https://chat.mibbit.com/?channel=%23native&server=irc.perl.org>
+
+=back
+
 =head1 SEE ALSO
 
 L<Alien::Build::Manual::AlienAuthor>,
