@@ -19,7 +19,7 @@ use base qw( Exporter );
 our @EXPORT = qw( alien_ok run_ok xs_ok ffi_ok with_subtest synthetic helper_ok interpolate_template_is );
 
 # ABSTRACT: Testing tools for Alien modules
-our $VERSION = '0.70_01'; # TRIAL VERSION
+our $VERSION = '0.71_01'; # TRIAL VERSION
 $VERSION = eval $VERSION;
 
 
@@ -158,6 +158,15 @@ sub xs_ok
   # modify it.
   $xs->{xs} = "@{[ $xs->{xs} ]}";
   $xs->{pxs} ||= {};
+  $xs->{cbuilder_compile} ||= {};
+  $xs->{link_compile}     ||= {};
+
+  if($xs->{cpp} || $xs->{'C++'})
+  {
+    $xs->{pxs}->{'C++'} = 1;
+    $xs->{cbuilder_compile}->{'C++'} = 1;
+  }
+
   my $verbose = $xs->{verbose};
   my $ok = 1;
   my @diag;
@@ -237,6 +246,7 @@ sub xs_ok
         $cb->compile(
           source               => $c_filename,
           extra_compiler_flags => [shellwords map { _flags $_, 'cflags' } @aliens],
+          %{ $xs->{cbuilder_compile} },
         );
       };
       ($obj, $@);
@@ -263,6 +273,7 @@ sub xs_ok
             objects            => [$obj],
             module_name        => $module,
             extra_linker_flags => [shellwords map { _flags $_, 'libs' } @aliens],
+            %{ $xs->{cbuilder_link} },
           );
         };
         ($lib, $@);
@@ -553,7 +564,7 @@ Test::Alien - Testing tools for Alien modules
 
 =head1 VERSION
 
-version 0.70_01
+version 0.71_01
 
 =head1 SYNOPSIS
 
@@ -760,12 +771,24 @@ The XS code.  This is the only required element.
 
 =item pxs
 
-The L<ExtUtils::ParseXS> arguments passes as a hash reference.
+Extra L<ExtUtils::ParseXS> arguments passed in as a hash reference.
+
+=item cbuilder_compile
+
+Extra The L<ExtUtils::CBuilder> arguments passed in as a hash reference.
+
+=item cbuilder_link
+
+Extra The L<ExtUtils::CBuilder> arguments passed in as a hash reference.
 
 =item verbose
 
 Spew copious debug information via test note.
 
+=item C++ or cpp
+
+XS should be compiled as C++.
+
 =back
 
 You can use the C<with_subtest> keyword to conditionally
